# appli-django

📦 **appli-django** est un outil en ligne de commande (CLI) qui permet de créer rapidement une structure d'application Django enrichie avec les fichiers utiles, y compris :

- `views.py`
- `urls.py`
- `forms.py`
- `serializers.py`
- Et le dossier `migrations/` avec `__init__.py`

---

## 🚀 Installation

### Depuis les sources (localement) :

1. Clone ou copie ce dépôt.
2. Place-toi dans le dossier du projet.
3. Installe le package :

```bash
pip install appli-django
appli-django <nom_de_ton_appli>
